@@ -22,31 +22,34 @@
 ##'
 ##' \item \eqn{RMSE}, the root mean squared error.
 ##'
-##' \item \eqn{r}, the Pearson correlation coefficient.
+##' \item \eqn{r}, the Pearson correlation coefficient. Note, can also
+##' supply and aurument \code{method} e.g. \code{method = "spearman"}
 ##'
-##' \item \eqn{IOA}, the Index of Agreement based on Willmott et
-##' al. (2011), which spans between -1 and +1 with values approaching
-##' +1 representing better model performance.
+##' \item \eqn{COE}, the \emph{Coefficient of Efficiency} based on
+##' Legates and McCabe (1999, 2012). There have been many suggestions
+##' for measuring model performance over the years, but the COE is a
+##' simple formulation which is easy to interpret.
 ##'
-##' An IOA of 0.5, for example, indicates that the sum of the
-##' error-magnitudes is one half of the sum of the observed-deviation
-##' magnitudes.  When IOA = 0.0, it signifies that the sum of the
-##' magnitudes of the errors and the sum of the observed-deviation
-##' magnitudes are equivalent. When IOA = -0.5, it indicates that the
-##' sum of the error-magnitudes is twice the sum of the perfect
-##' model-deviation and observed-deviation magnitudes. Values of IOA
-##' near -1.0 can mean that the model-estimated deviations about O are
-##' poor estimates of the observed deviations; but, they also can mean
-##' that there simply is little observed variability - so some caution
-##' is needed when the IOA approaches -1.
+##' A perfect model has a COE = 1. As noted by Legates and McCabe
+##' although the COE has no lower bound, a value of COE = 0.0 has a
+##' fundamental meaning. It implies that the model is no more able to
+##' predict the observed values than does the observed
+##' mean. Therefore, since the model can explain no more of the
+##' variation in the observed values than can the observed mean, such
+##' a model can have no predictive advantage.
 ##'
+##' For negative values of COE, the model is less effective than the
+##' observed mean in predicting the variation in the
+##' observations.
 ##' }
 ##'
 ##' All statistics are based on complete pairs of \code{mod} and \code{obs}.
 ##'
-##' Conditioning is possible through setting \code{type}.
+##' Conditioning is possible through setting \code{type}, which can be
+##' a vector e.g. \code{type = c("weekday", "season")}.
+##'
+##' Details of the formulas are given in the openair manual.
 ##'
-
 ##'
 ##' @param mydata A data frame.
 ##' @param mod Name of a variable in \code{mydata} that respresents modelled
@@ -61,32 +64,35 @@
 ##' = "season"} will produce four sets of statistics --- one for each
 ##' season.
 ##'
-##' It is also possible to choose \code{type} as another variable in the data
-##'   frame. If that variable is numeric, then the data will be split into four
-##'   quantiles (if possible) and labelled accordingly. If type is an existing
-##'   character or factor variable, then those categories/levels will be used
-##'   directly. This offers great flexibility for understanding the variation
-##'   of different variables and how they depend on one another.
+##' It is also possible to choose \code{type} as another variable in
+##' the data frame. If that variable is numeric, then the data will be
+##' split into four quantiles (if possible) and labelled
+##' accordingly. If type is an existing character or factor variable,
+##' then those categories/levels will be used directly. This offers
+##' great flexibility for understanding the variation of different
+##' variables and how they depend on one another.
 ##'
 ##' More than one type can be considered e.g. \code{type = c("season",
-##'   "weekday")} will produce statistics split by season and day of the week.
+##' "weekday")} will produce statistics split by season and day of the
+##' week.
 ##' @param rank.name Simple model ranking can be carried out if
 ##' \code{rank.name} is supplied. \code{rank.name} will generally
 ##' refer to a column representing a model name, which is to
-##' ranked. The ranking is based the Index of Agreement performance,
-##' as that indicator is arguably the best single model performance
-##' indicator available.
-##'
-##'
+##' ranked. The ranking is based the COE performance, as that
+##' indicator is arguably the best single model performance indicator
+##' available.
 ##' @param ... Other aruments to be passed to \code{cutData} e.g.
 ##'   \code{hemisphere = "southern"}
 ##' @export
 ##' @return Returns a data frame with model evaluation statistics.
 ##' @author David Carslaw
 ##' @references
-##' Willmott, C.J., Robeson, S.M., Matsuura, K., 2011. A
-##' refined index of model performance. International Journal of
-##' Climatology.
+##' Legates DR, McCabe GJ. (1999). Evaluating the use of goodness-of-fit
+##' measures in hydrologic and hydroclimatic model validation. Water
+##' Resources Research 35(1): 233-241.
+##'
+##' Legates DR, McCabe GJ. (2012). A refined index of model
+##' performance: a rejoinder, International Journal of Climatology.
 ##' @keywords methods
 ##' @examples
 ##'
@@ -123,11 +129,11 @@ modStats <- function(mydata,  mod = "mod", obs = "obs", type = "default", rank.n
     res.NMB <- ddply(mydata, type, NMB, mod, obs)
     res.NMGE <- ddply(mydata, type, NMGE, mod, obs)
     res.RMSE <- ddply(mydata, type, RMSE, mod, obs)
-    res.r <- ddply(mydata, type, r, mod, obs)
-    res.IOA <- ddply(mydata, type, IOA, mod, obs)
+    res.r <- ddply(mydata, type, r, mod, obs, ...)
+    res.COE <- ddply(mydata, type, COE, mod, obs)
 
     ## merge them all into one data frame
-    results <- list(res.n, res.FAC, res.MB, res.MGE, res.NMB, res.NMGE, res.RMSE, res.r, res.IOA)
+    results <- list(res.n, res.FAC, res.MB, res.MGE, res.NMB, res.NMGE, res.RMSE, res.r, res.COE)
     results <- Reduce(function(x, y, by = type) merge(x, y, by = type, all = TRUE), results)
 
     results <- sortDataFrame(results, key = type)
@@ -146,6 +152,7 @@ modStats <- function(mydata,  mod = "mod", obs = "obs", type = "default", rank.n
 
     }
 
+    results <- na.omit(results)
     results
 
 }
@@ -167,12 +174,13 @@ sortDataFrame <- function(x, key, ...) {
 
 rankModels <- function(mydata, rank.name = "group") {
 
-    ## sort by IOA
-    mydata <- sortDataFrame(mydata, "IOA", decreasing = TRUE)
+    ## sort by COE
+    mydata <- sortDataFrame(mydata, "COE", decreasing = TRUE)
 }
 
 ## number of valid readings
 n <- function(x, mod = "mod", obs = "obs") {
+
     x <- na.omit(x[ , c(mod, obs)])
     res <- nrow(x)
     data.frame(n = res)
@@ -228,21 +236,19 @@ RMSE <- function(x, mod = "mod", obs = "obs") {
 }
 
 ## correlation coefficient
-r <- function(x, mod = "mod", obs = "obs") {
+r <- function(x, mod = "mod", obs = "obs", ...) {
+
     x <- na.omit(x[ , c(mod, obs)])
-    res <- suppressWarnings(cor(x[ , mod], x[ , obs])) ## when SD=0
+    res <- suppressWarnings(cor(x[ , mod], x[ , obs], ...)) ## when SD=0
     data.frame(r = res)
 }
 
-##  Index of Agreement
-IOA <- function(x, mod = "mod", obs = "obs") {
+##  Coefficient of Efficiency
+COE <- function(x, mod = "mod", obs = "obs") {
     x <- na.omit(x[ , c(mod, obs)])
 
-    LHS <- sum(abs(x[, mod] - x[, obs]))
-    RHS <- 2 * sum(abs(x[, obs] - mean(x[, obs])))
+    res <-  1 - sum(abs(x[, mod] - x[, obs])) / sum(abs(x[, obs] - mean(x[, obs])))
 
-    if (LHS <= RHS) res <- 1 - LHS / RHS else res <- RHS / LHS - 1
-
-    data.frame(IOA = res)
+    data.frame(COE = res)
 }
 
